@@ -1,28 +1,51 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_hyperlinks.py 8831 2021-09-20 13:03:39Z milde $
+# $Id: test_hyperlinks.py 10170 2025-06-16 12:36:11Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
 Tests for docutils.transforms.references.Hyperlinks.
 """
-from __future__ import absolute_import
+
+from pathlib import Path
+import sys
+import unittest
 
 if __name__ == '__main__':
-    import __init__
-from test_transforms import DocutilsTestSupport
+    # prepend the "docutils root" to the Python library path
+    # so we import the local `docutils` package.
+    sys.path.insert(0, str(Path(__file__).resolve().parents[2]))
+
+from docutils.frontend import get_default_settings
+from docutils.parsers.rst import Parser
 from docutils.transforms.references import PropagateTargets, \
      AnonymousHyperlinks, IndirectHyperlinks, ExternalTargets, \
      InternalTargets, DanglingReferences
-from docutils.parsers.rst import Parser
+from docutils.transforms.universal import TestMessages
+from docutils.utils import new_document
 
 
-def suite():
-    parser = Parser()
-    s = DocutilsTestSupport.TransformTestSuite(parser)
-    s.generateTests(totest)
-    return s
+class TransformTestCase(unittest.TestCase):
+    maxDiff = None
+
+    def test_transforms(self):
+        parser = Parser()
+        settings = get_default_settings(Parser)
+        settings.warning_stream = ''
+        for name, (transforms, cases) in totest.items():
+            for casenum, (case_input, case_expected) in enumerate(cases):
+                with self.subTest(id=f'totest[{name!r}][{casenum}]'):
+                    document = new_document('test data', settings.copy())
+                    parser.parse(case_input, document)
+                    # Don't do a ``populate_from_components()`` because that
+                    # would enable the Transformer's default transforms.
+                    document.transformer.add_transforms(transforms)
+                    document.transformer.add_transform(TestMessages)
+                    document.transformer.apply_transforms()
+                    output = document.pformat()
+                    self.assertEqual(case_expected, output)
+
 
 totest = {}
 
@@ -352,7 +375,7 @@ Another reference to the same `embedded alias`_.
         An \n\
         <reference name="embedded alias" refuri="ham.py">
             embedded alias
-        <target names="embedded\\ alias" refuri="ham.py">
+        <target ids="embedded-alias" names="embedded\\ alias" refuri="ham.py">
         .
     <paragraph>
         Another reference to the same \n\
@@ -384,17 +407,17 @@ An `embedded alias <alias_>`_ with unknown reference.
         An \n\
         <problematic ids="problematic-1" refid="system-message-2">
             `embedded alias <alias_>`_
-        <target names="embedded\\ alias" refname="alias">
+        <target ids="embedded-alias" names="embedded\\ alias" refname="alias">
          with unknown reference.
     <system_message ids="system-message-1" level="3" line="1" source="test data" type="ERROR">
         <paragraph>
-            Indirect hyperlink target "embedded alias"  refers to target "alias", which does not exist.
+            Indirect hyperlink target "embedded alias" (id="embedded-alias") refers to target "alias", which does not exist.
     <system_message backrefs="problematic-1" ids="system-message-2" level="3" line="1" source="test data" type="ERROR">
         <paragraph>
             Unknown target name: "alias".
     <system_message level="1" line="1" source="test data" type="INFO">
         <paragraph>
-            Hyperlink target "embedded alias" is not referenced.\
+            Hyperlink target "embedded alias" is not referenced.
 """],
 ["""\
 An embedded URI with trailing underline:
@@ -415,7 +438,7 @@ See `Element \\<a>`_, `Element <b\\>`_, and `Element <c>\\ `_.
 
 .. _`Element <a>`:
 .. _`Element <b>`:
-.. _`Element <c>`: elements.txt
+.. _`Element <c>`: elements.rst
 """,
 """\
 <document source="test data">
@@ -423,18 +446,18 @@ See `Element \\<a>`_, `Element <b\\>`_, and `Element <c>\\ `_.
         Hyperlinks with angle-bracketed text need escaping.
     <paragraph>
         See \n\
-        <reference name="Element <a>" refuri="elements.txt">
+        <reference name="Element <a>" refuri="elements.rst">
             Element <a>
         , \n\
-        <reference name="Element <b>" refuri="elements.txt">
+        <reference name="Element <b>" refuri="elements.rst">
             Element <b>
         , and \n\
-        <reference name="Element <c>" refuri="elements.txt">
+        <reference name="Element <c>" refuri="elements.rst">
             Element <c>
         .
     <target refid="element-a">
     <target refid="element-b">
-    <target ids="element-c element-b element-a" names="element\\ <c> element\\ <b> element\\ <a>" refuri="elements.txt">
+    <target ids="element-c element-b element-a" names="element\\ <c> element\\ <b> element\\ <a>" refuri="elements.rst">
 """],
 ["""\
 .. _target:
@@ -741,7 +764,7 @@ Duplicate external target_'s (different URIs):
             target_
         's (different URIs):
     <target dupnames="target" ids="target" refuri="first">
-    <system_message backrefs="target-1" level="2" line="5" source="test data" type="WARNING">
+    <system_message level="2" line="5" source="test data" type="WARNING">
         <paragraph>
             Duplicate explicit target name: "target".
     <target dupnames="target" ids="target-1" refuri="second">
@@ -761,7 +784,7 @@ Duplicate external targets (different URIs) without reference:
     <paragraph>
         Duplicate external targets (different URIs) without reference:
     <target dupnames="target" ids="target" refuri="first">
-    <system_message backrefs="target-1" level="2" line="5" source="test data" type="WARNING">
+    <system_message level="2" line="5" source="test data" type="WARNING">
         <paragraph>
             Duplicate explicit target name: "target".
     <target dupnames="target" ids="target-1" refuri="second">
@@ -937,5 +960,4 @@ Duplicate manual footnote labels, with reference ([1]_):
 
 
 if __name__ == '__main__':
-    import unittest
-    unittest.main(defaultTest='suite')
+    unittest.main()
